import {
  stack,
  schemeTableau10,
  extent,
  scaleLinear,
} from 'd3';

export const stacked = (
  selection,
  {
    data,
    height,
    width,
    xValue,
    yValue,
    totalValue,
    mediumKeys,
  }
) => {
  const xScale = d3
    .scaleBand(data.map(xValue), [40, width - 0])
    .padding(0.2);

  const yScale = d3.scaleLinear(
    [0, d3.max(data, totalValue)],
    [height - 30, 40]
  );


  const xAxis = d3
    .axisBottom(xScale)
    .tickSizeOuter(0);

  const yAxis = d3.axisLeft(yScale);

  const chartData = d3.stack().keys(mediumKeys);
  const stackedData = chartData(data);

  selection
    .selectAll('g')
    .data(mediumKeys)
    .join('g')
    .attr(
      'transform',
      (d, i) => `translate(${i * 100},5)`
    )
    .call((g) =>
      g
        .append('rect')
        .attr('width', 20)
        .attr('height', 20)
        .style(
          'fill',
          (d, i) => schemeTableau10[i]
        )
    )
    .call((g) =>
      g
        .append('text')
        .attr('y', 10)
        .attr('x', 25)
        .attr('dy', '0.35em')
        .style('font-size', 10)
        .style('font-family', 'sans-serif')
        .text(
          (d) => d[0] + d.slice(1).toLowerCase()
        )
    );

  const groups = selection
    .append('g')
    .selectAll('g')
    .data(stackedData)
    .join('g')
    .style('fill', (d, i) => schemeTableau10[i]);

  groups
    .selectAll('rect')
    .data((d) => d)
    .join('rect')
    .attr('x', (d) => xScale(d.data.date))
    .attr('y', (d) => yScale(d[1]))
    .attr(
      'height',
      (d) => yScale(d[0]) - yScale(d[1])
    )
    .attr('width', xScale.bandwidth());

  selection
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - 20})`
    )
    .call(xAxis);

  selection
    .append('g')
    .attr('transform', `translate(${50},0)`)
    .call(yAxis)
    .select('.domain');
};
